=======
Credits
=======

Development Lead
----------------

* `Stefano H. Baruffaldi <https://github.com/ste210>`_
* `Michael E. Rose <https://github.com/Michael-E-Rose>`_

Contributors
------------

See `contributors <https://github.com/sosia-dev/sosia/graphs/contributors>`_
